@@ -1,2 +1,4 @@
 from .connections.websocket import WebSocket
-from .rubika import Client
\ No newline at end of file
+from .rubika import Client
+from .tools import Tools
+import exceptions
\ No newline at end of file
